from timespy import timer
import time

def test_profile():
    @timer
    def fast_function():
        pass

    fast_function()
    assert fast_function.exec_time >= 0

def test_slow_function():
    @timer
    def slow_function():
        time.sleep(1)

    slow_function()
    assert slow_function.exec_time >= 1.0



import time
import functools

def timer(func):
    """Profiler decorator to measure execution time of functions."""
    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        start_time = time.perf_counter()
        result = func(*args, **kwargs)
        end_time = time.perf_counter()
        wrapper.exec_time = end_time - start_time  # Store execution time in wrapper.exec_time
        return result
    
    wrapper.exec_time = 0  # Initialize exec_time before function execution
    return wrapper




from setuptools import setup, find_packages

setup(
    name="timespy",
    version="1.0.0",
    description="Timespy is a lightweight Python decorator that measures the execution time of functions, providing an easy way to analyze and optimize performance.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Croketillo",
    author_email="croketillo@gmail.com",
    url="https://github.com/croketillo/timespy", 
    license="GPL-3.0-or-later",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
    "Intended Audience :: Developers",
    "Topic :: Software Development :: Libraries",
    "Topic :: Software Development :: Libraries :: Python Modules",
    "Topic :: Utilities",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: 3.11",
    "Programming Language :: Python :: 3.12",
    "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
